@@ -76,7 +76,7 @@ class HltTap(BaseModel):
     tip_oms = models.ForeignKey("OmsKlTipOms", db_column="rf_kl_TipOMSID", **FK_DEFAULT)
     num = models.IntegerField(db_column="Num", default=0)
 
-    flags = models.IntegerField(db_column="Flags")
+    flags = models.IntegerField(db_column="Flags", default=0)
 
     class Meta:
         managed = False
