@@ -7,7 +7,7 @@ class OmsLpu(BaseModel):
     """
 
     id = models.AutoField(db_column="LPUID", primary_key=True)
-    uuid = models.CharField(db_column="GUIDLPU", max_length=36, unique=True, default=uuid.uuid4)
+    uuid = models.CharField(db_column="GUIDLPU", max_length=36, unique=True, default=uuid4)
     okato = models.ForeignKey("OmsOkato", models.DO_NOTHING, db_column="rf_OKATOID")
     c_ogrn = models.CharField(db_column="C_OGRN", max_length=15)
     m_names = models.CharField(db_column="M_NAMES", max_length=200)
